@@ -1,7 +1,7 @@
 _base_ = './yolox_s_8xb16_300e_coco.py'
 
 # model settings
-model = dict(model_type='l')
+model = dict(model_type='l', head=dict(model_type='l', ))
 
 data = dict(imgs_per_gpu=8, workers_per_gpu=4)
 
