@@ -1,4 +1,4 @@
 _base_ = './yolox_s_8xb16_300e_coco.py'
 
 # model settings
-model = dict(model_type='m')
+model = dict(model_type='m', head=dict(model_type='m', ))
