@@ -25,11 +25,13 @@ class ClsEvaluator(Evaluator):
         '''
 
         Args:
-            top_k: tuple of int, evaluate top_k acc
+            top_k (int, tuple): int or tuple of int, evaluate top_k acc
             dataset_name: eval dataset name
             metric_names: eval metrics name
             neck_num: some model contains multi-neck to support multitask, neck_num means use the no.neck_num  neck output of model to eval
         '''
+        if isinstance(topk, int):
+            topk = (topk, )
         self._topk = topk
         self.dataset_name = dataset_name
         self.neck_num = neck_num
@@ -145,4 +147,92 @@ class ClsEvaluator(Evaluator):
         return eval_res
 
 
+@EVALUATORS.register_module
+class MultiLabelEvaluator(Evaluator):
+    """ Multilabel Classification evaluator.
+  """
+
+    def __init__(self, dataset_name=None, metric_names=['mAP']):
+        '''
+
+        Args:
+            dataset_name: eval dataset name
+            metric_names: eval metrics name
+        '''
+        self.dataset_name = dataset_name
+
+        super(MultiLabelEvaluator, self).__init__(dataset_name, metric_names)
+
+    def _evaluate_impl(self, predictions, gt_labels):
+        preds = torch.sigmoid(predictions['neck'])
+
+        map_out = self.mAP(preds, gt_labels)
+        eval_res = {
+            'mAP': map_out,
+        }
+        return eval_res
+
+    def mAP(self, pred, target):
+        """Calculate the mean average precision with respect of classes.
+        Args:
+            pred (torch.Tensor | np.ndarray): The model prediction with shape
+                (N, C), where C is the number of classes.
+            target (torch.Tensor | np.ndarray): The target of each prediction with
+                shape (N, C), where C is the number of classes. 1 stands for
+                positive examples, 0 stands for negative examples and -1 stands for
+                difficult examples.
+        Returns:
+            float: A single float as mAP value.
+        """
+        if isinstance(pred, torch.Tensor) and isinstance(target, torch.Tensor):
+            pred = pred.detach().cpu().numpy()
+            target = target.detach().cpu().numpy()
+        elif not (isinstance(pred, np.ndarray)
+                  and isinstance(target, np.ndarray)):
+            raise TypeError('pred and target should both be torch.Tensor or'
+                            'np.ndarray')
+
+        assert pred.shape == \
+            target.shape, 'pred and target should be in the same shape.'
+        num_classes = pred.shape[1]
+        ap = np.zeros(num_classes)
+        mean_ap = ap.mean() * 100.0
+        return mean_ap
+
+    def average_precision(self, pred, target):
+        r"""Calculate the average precision for a single class.
+        AP summarizes a precision-recall curve as the weighted mean of maximum
+        precisions obtained for any r'>r, where r is the recall:
+        .. math::
+            \text{AP} = \sum_n (R_n - R_{n-1}) P_n
+        Note that no approximation is involved since the curve is piecewise
+        constant.
+        Args:
+            pred (np.ndarray): The model prediction with shape (N, ).
+            target (np.ndarray): The target of each prediction with shape (N, ).
+        Returns:
+            float: a single float as average precision value.
+        """
+        eps = np.finfo(np.float32).eps
+
+        # sort examples
+        sort_inds = np.argsort(-pred)
+        sort_target = target[sort_inds]
+
+        # count true positive examples
+        pos_inds = sort_target == 1
+        tp = np.cumsum(pos_inds)
+        total_pos = tp[-1]
+
+        # count not difficult examples
+        pn_inds = sort_target != -1
+        pn = np.cumsum(pn_inds)
+
+        tp[np.logical_not(pos_inds)] = 0
+        precision = tp / np.maximum(pn, eps)
+        ap = np.sum(precision) / np.maximum(total_pos, eps)
+        return ap
+
+
 METRICS.register_default_best_metric(ClsEvaluator, 'neck_top1', 'max')
+METRICS.register_default_best_metric(MultiLabelEvaluator, 'mAP', 'max')
