@@ -3,7 +3,7 @@
 from easycv.utils.import_utils import check_numpy
 check_numpy()
 from . import (classification, detection, detection3d, face, ocr, pose,
-               segmentation, selfsup, shared)
+               segmentation, selfsup, shared, video_recognition)
 from .builder import (build_dali_dataset, build_dataset, build_datasource,
                       build_sampler)
 from .loader import (DistributedGivenIterationSampler, DistributedGroupSampler,
