@@ -10,8 +10,10 @@ from io import StringIO
 
 from tqdm import tqdm
 
+from easycv.framework.errors import ValueError
+
 OSS_PREFIX = 'oss://'
-URL_PREFIX = 'https://'
+URL_PREFIX = ('https://', 'http://')
 
 
 def create_namedtuple(**kwargs):
@@ -31,6 +33,7 @@ def url_path_exists(url):
         urllib.request.urlopen(url).code
     except Exception as err:
         print(err)
+        return False
     return True
 
 
