@@ -1,8 +1,8 @@
 #!/usr/bin/env python3
 # Copyright (c) 2014-2021 Megvii Inc. All rights reserved.
 from .boxes import (batched_nms, bbox2result, bbox_overlaps, bboxes_iou,
-                    box_cxcywh_to_xyxy, box_xyxy_to_cxcywh, distance2bbox,
-                    fp16_clamp, generalized_box_iou)
+                    box_cxcywh_to_xyxy, box_iou, box_xyxy_to_cxcywh,
+                    distance2bbox, fp16_clamp, generalized_box_iou)
 from .generator import MlvlPointGenerator
 from .misc import (accuracy, gen_encoder_output_proposals,
                    gen_sineembed_for_position, interpolate, inverse_sigmoid,
