@@ -646,20 +646,22 @@ class BEVFormerHead(AnchorFreeHead):
 
             gt_bboxes_list_aux = []
             gt_labels_list_aux = []
-            for gt_bboxes, gt_labels in zip(gt_bboxes_list, gt_labels_list):
-                gt_bboxes_list_aux.append(
-                    gt_bboxes.repeat(self.one2many_gt_mul, 1))
-                gt_labels_list_aux.append(
-                    gt_labels.repeat(self.one2many_gt_mul))
+            # for gt_bboxes, gt_labels in zip(gt_bboxes_list, gt_labels_list):
+            #     gt_bboxes_list_aux.append(
+            #         gt_bboxes.repeat(self.one2many_gt_mul, 1))
+            #     gt_labels_list_aux.append(
+            #         gt_labels.repeat(self.one2many_gt_mul))
             # for classwise multiply
-            # for gt_bboxes, gt_labels in zip(gt_bboxes_list,gt_labels_list):
-            #     gt_bboxes_aux = []
-            #     gt_labels_aux = []
-            #     for gt_bbox, gt_label in zip(gt_bboxes, gt_labels):
-            #         gt_bboxes_aux += [gt_bbox]*self.one2many_gt_mul[gt_label]
-            #         gt_labels_aux += [gt_label]*self.one2many_gt_mul[gt_label]
-            #     gt_bboxes_list_aux.append(torch.stack(gt_bboxes_aux))
-            #     gt_labels_list_aux.append(torch.stack(gt_labels_aux))
+            for gt_bboxes, gt_labels in zip(gt_bboxes_list, gt_labels_list):
+                gt_bboxes_aux = []
+                gt_labels_aux = []
+                for gt_bbox, gt_label in zip(gt_bboxes, gt_labels):
+                    gt_bboxes_aux += [gt_bbox] * self.one2many_gt_mul[gt_label]
+                    gt_labels_aux += [gt_label
+                                      ] * self.one2many_gt_mul[gt_label]
+                gt_bboxes_list_aux.append(torch.stack(gt_bboxes_aux))
+                gt_labels_list_aux.append(torch.stack(gt_labels_aux))
+
             all_gt_bboxes_list_aux = [
                 gt_bboxes_list_aux for _ in range(num_dec_layers)
             ]
