@@ -4,7 +4,7 @@ from .det_db_loss import DBLoss
 from .face_keypoint_loss import FacePoseLoss, WingLossWithPose
 from .focal_loss import FocalLoss, VarifocalLoss
 from .iou_loss import GIoULoss, IoULoss, YOLOX_IOULoss
-from .l1_loss import L1Loss
+from .l1_loss import L1Loss, SmoothL1Loss
 from .mse_loss import JointsMSELoss
 from .ocr_rec_multi_loss import MultiLoss
 from .pytorch_metric_learning import (AMSoftmaxLoss,
@@ -22,5 +22,5 @@ __all__ = [
     'FocalLoss2d', 'DistributeMSELoss', 'CrossEntropyLossWithLabelSmooth',
     'AMSoftmaxLoss', 'ModelParallelSoftmaxLoss', 'ModelParallelAMSoftmaxLoss',
     'SoftTargetCrossEntropy', 'CDNCriterion', 'DNCriterion', 'DBLoss',
-    'HungarianMatcher', 'SetCriterion', 'L1Loss', 'MultiLoss'
+    'HungarianMatcher', 'SetCriterion', 'L1Loss', 'MultiLoss', 'SmoothL1Loss'
 ]
