@@ -4,7 +4,7 @@ import torch.nn as nn
 import torch.nn.functional as F
 
 from easycv.models.detection.utils import (accuracy, box_cxcywh_to_xyxy,
-                                           generalized_box_iou)
+                                           box_iou, generalized_box_iou)
 from easycv.models.loss.focal_loss import py_sigmoid_focal_loss
 from easycv.utils.dist_utils import get_dist_info, is_dist_available
 
@@ -127,6 +127,73 @@ class SetCriterion(nn.Module):
 
         return losses
 
+    def loss_centerness(self, outputs, targets, indices, num_boxes):
+
+        def ref2ltrb(ref, xyxy):
+            lt = ref - xyxy[..., :2]
+            rb = xyxy[..., 2:] - ref
+            ltrb = torch.cat([lt, rb], dim=-1)
+            return ltrb
+
+        def compute_centerness_targets(box_targets):
+            left_right = box_targets[:, [0, 2]]
+            top_bottom = box_targets[:, [1, 3]]
+            centerness = (left_right.min(-1)[0] / left_right.max(-1)[0]) * (
+                top_bottom.min(-1)[0] / top_bottom.max(-1)[0])
+            return torch.sqrt(centerness)
+
+        assert 'pred_centers' in outputs
+        idx = self._get_src_permutation_idx(indices)
+        src_centers = outputs['pred_centers'][idx]  # logits
+        src_centers = src_centers.squeeze(1)
+        target_boxes = torch.cat(
+            [t['boxes'][i] for t, (_, i) in zip(targets, indices)], dim=0)
+
+        assert 'refpts' in outputs
+        src_refpts = outputs['refpts'][idx]  # sigmoided
+        assert src_refpts.shape[-1] == 2
+
+        target_boxes_xyxy = box_cxcywh_to_xyxy(target_boxes)
+        target_boxes_ltrb = ref2ltrb(src_refpts, target_boxes_xyxy)
+        is_in_box = torch.sum(target_boxes_ltrb >= 0, dim=-1) == 4
+
+        src_centers = src_centers[is_in_box]
+        target_boxes_ltrb = target_boxes_ltrb[is_in_box]
+
+        target_boxes_ltrb = target_boxes_ltrb.detach()
+
+        losses = {}
+        if len(target_boxes_ltrb) == 0:
+            losses['loss_center'] = src_centers.sum(
+            ) * 0  # prevent unused parameters
+        else:
+            target_centers = compute_centerness_targets(target_boxes_ltrb)
+            loss_center = F.binary_cross_entropy_with_logits(
+                src_centers, target_centers, reduction='none')
+            losses['loss_center'] = loss_center.sum() / num_boxes
+
+        return losses
+
+    def loss_iouaware(self, outputs, targets, indices, num_boxes):
+        assert 'pred_ious' in outputs
+        idx = self._get_src_permutation_idx(indices)
+        src_ious = outputs['pred_ious'][idx]  # logits
+        src_ious = src_ious.squeeze(1)
+        src_boxes = outputs['pred_boxes'][idx]
+        target_boxes = torch.cat(
+            [t['boxes'][i] for t, (_, i) in zip(targets, indices)], dim=0)
+
+        iou = torch.diag(
+            box_iou(
+                box_cxcywh_to_xyxy(src_boxes),
+                box_cxcywh_to_xyxy(target_boxes))[0])
+
+        losses = {}
+        loss_iouaware = F.binary_cross_entropy_with_logits(
+            src_ious, iou, reduction='none')
+        losses['loss_iouaware'] = loss_iouaware.sum() / num_boxes
+        return losses
+
     def _get_src_permutation_idx(self, indices):
         # permute predictions following indices
         batch_idx = torch.cat(
@@ -146,6 +213,8 @@ class SetCriterion(nn.Module):
             'labels': self.loss_labels,
             'cardinality': self.loss_cardinality,
             'boxes': self.loss_boxes,
+            'centerness': self.loss_centerness,
+            'iouaware': self.loss_iouaware,
         }
         assert loss in loss_map, f'do you really want to compute {loss} loss?'
         return loss_map[loss](outputs, targets, indices, num_boxes, **kwargs)
@@ -156,7 +225,6 @@ class SetCriterion(nn.Module):
              outputs: dict of tensors, see the output specification of the model for the format
              targets: list of dicts, such that len(targets) == batch_size.
                       The expected keys in each dict depends on the losses applied, see each loss' doc
-
              return_indices: used for vis. if True, the layer0-5 indices will be returned as well.
         """
 
@@ -200,9 +268,6 @@ class SetCriterion(nn.Module):
                 if return_indices:
                     indices_list.append(indices)
                 for loss in self.losses:
-                    if loss == 'masks':
-                        # Intermediate masks losses are too costly to compute, we ignore them.
-                        continue
                     kwargs = {}
                     if loss == 'labels':
                         # Logging is enabled only for the last layer
@@ -223,9 +288,6 @@ class SetCriterion(nn.Module):
             if return_indices:
                 indices_list.append(indices)
             for loss in self.losses:
-                if loss == 'masks':
-                    # Intermediate masks losses are too costly to compute, we ignore them.
-                    continue
                 kwargs = {}
                 if loss == 'labels':
                     # Logging is enabled only for the last layer
@@ -321,9 +383,15 @@ class CDNCriterion(SetCriterion):
             losses.update(l_dict)
         else:
             l_dict = dict()
-            l_dict['loss_bbox_dn'] = torch.as_tensor(0.).to('cuda')
-            l_dict['loss_giou_dn'] = torch.as_tensor(0.).to('cuda')
-            l_dict['loss_ce_dn'] = torch.as_tensor(0.).to('cuda')
+            if 'labels' in self.losses:
+                l_dict['loss_ce_dn'] = torch.as_tensor(0.).to('cuda')
+            if 'boxes' in self.losses:
+                l_dict['loss_bbox_dn'] = torch.as_tensor(0.).to('cuda')
+                l_dict['loss_giou_dn'] = torch.as_tensor(0.).to('cuda')
+            if 'centerness' in self.losses:
+                l_dict['loss_center_dn'] = torch.as_tensor(0.).to('cuda')
+            if 'iouaware' in self.losses:
+                l_dict['loss_iouaware_dn'] = torch.as_tensor(0.).to('cuda')
             losses.update(l_dict)
 
         for i in range(aux_num):
@@ -348,9 +416,15 @@ class CDNCriterion(SetCriterion):
                 losses.update(l_dict)
             else:
                 l_dict = dict()
-                l_dict['loss_bbox_dn'] = torch.as_tensor(0.).to('cuda')
-                l_dict['loss_giou_dn'] = torch.as_tensor(0.).to('cuda')
-                l_dict['loss_ce_dn'] = torch.as_tensor(0.).to('cuda')
+                if 'labels' in self.losses:
+                    l_dict['loss_ce_dn'] = torch.as_tensor(0.).to('cuda')
+                if 'boxes' in self.losses:
+                    l_dict['loss_bbox_dn'] = torch.as_tensor(0.).to('cuda')
+                    l_dict['loss_giou_dn'] = torch.as_tensor(0.).to('cuda')
+                if 'centerness' in self.losses:
+                    l_dict['loss_center_dn'] = torch.as_tensor(0.).to('cuda')
+                if 'iouaware' in self.losses:
+                    l_dict['loss_iouaware_dn'] = torch.as_tensor(0.).to('cuda')
                 l_dict = {
                     k + f'_{i}':
                     v * (self.weight_dict[k] if k in self.weight_dict else 1.0)
