@@ -4,5 +4,5 @@ from easycv.utils.registry import Registry, build_from_cfg
 PREDICTORS = Registry('predictor')
 
 
-def build_predictor(cfg):
-    return build_from_cfg(cfg, PREDICTORS, default_args=None)
+def build_predictor(cfg, default_args=None):
+    return build_from_cfg(cfg, PREDICTORS, default_args=default_args)
