@@ -3,6 +3,7 @@ import os.path as osp
 import platform
 import sys
 import tempfile
+import warnings
 from importlib import import_module
 
 from mmcv import Config, import_modules_from_strings
@@ -213,8 +214,8 @@ def mmcv_file2dict_base(ori_filename,
         for f in base_filename:
             base_cfg_path = check_base_cfg_path(
                 f, ori_filename, easycv_root=easycv_root)
-            _cfg_dict, _cfg_text = mmcv_file2dict_base(base_cfg_path,
-                                                       first_order_params)
+            _cfg_dict, _cfg_text = mmcv_file2dict_base(
+                base_cfg_path, first_order_params, easycv_root=easycv_root)
             cfg_dict_list.append(_cfg_dict)
             cfg_text_list.append(_cfg_text)
 
@@ -293,6 +294,11 @@ def adapt_pai_params(cfg_dict, class_list_params=None):
 
 def init_path(ori_filename):
     easycv_root = osp.dirname(easycv.__file__)  # easycv package root path
+    if not osp.exists(osp.join(easycv_root, 'configs')):
+        if osp.exists(osp.join(osp.dirname(easycv_root), 'configs')):
+            easycv_root = osp.dirname(easycv_root)
+        else:
+            raise ValueError('easycv root does not exist!')
     parse_ori_filename = ori_filename.split('/')
     if parse_ori_filename[0] == 'configs' or parse_ori_filename[
             0] == 'benchmarks':
@@ -569,4 +575,13 @@ CONFIG_TEMPLATE_ZOO = {
     # pose
     'TOPDOWN_HRNET': 'configs/config_templates/topdown_hrnet_w48_udp.py',
     'TOPDOWN_LITEHRNET': 'configs/config_templates/topdown_litehrnet_30.py',
+
+    # video_classification
+    'X3D_XS': 'configs/video_recognition/x3d/x3d_xs.py',
+    'X3D_M': 'configs/video_recognition/x3d/x3d_m.py',
+    'X3D_L': 'configs/video_recognition/x3d/x3d_l.py',
+    'VIDEO_SWIN_T': 'configs/video_recognition/swin/video_swin_tiny.py',
+    'VIDEO_SWIN_S': 'configs/video_recognition/swin/video_swin_s.py',
+    'VIDEO_SWIN_B': 'configs/video_recognition/swin/video_swin_b.py',
+    'SWIN_BERT': 'configs/video_recognition/clipbert/clipbert_multilabel.py',
 }
